==> ejc-equipment-api-3.0.0-20220730.104733-357-sources.jar: com/ejianc/business/equipment/vo/RentUseRecordLeftVO.java <==
package com.ejianc.business.equipment.vo;

import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 租赁设备使用记录
 * </p>
 *
 * @author yqls
 * @since 2020-06-11
 */
public class RentUseRecordLeftVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同编码
     */
    private String billCode;
    /**
     * 合同主键
     */
    private Long contractId;

    private Long projectId;
    private Integer whetherToContract;

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Integer getWhetherToContract() {
        return whetherToContract;
    }

    public void setWhetherToContract(Integer whetherToContract) {
        this.whetherToContract = whetherToContract;
    }
}

==> ejc-equipment-api-3.0.0-20240712.071959-490-sources.jar: com/ejianc/business/equipment/vo/RentUseRecordLeftVO.java <==
package com.ejianc.business.equipment.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 租赁设备使用记录
 * </p>
 *
 * @author yqls
 * @since 2020-06-11
 */
public class RentUseRecordLeftVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同编码
     */
    private String billCode;
    /**
     * 合同主键
     */
    private Long contractId;

    private Long projectId;
    /**
     * 供应商
     */
    private Long supplierId;
    private Integer whetherToContract;
    /**
     * 是否被零星付款使用 0 未使用 1 使用
     */
    private Integer sporadicUseFlag;

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Integer getWhetherToContract() {
        return whetherToContract;
    }

    public void setWhetherToContract(Integer whetherToContract) {
        this.whetherToContract = whetherToContract;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Integer getSporadicUseFlag() {
        return sporadicUseFlag;
    }

    public void setSporadicUseFlag(Integer sporadicUseFlag) {
        this.sporadicUseFlag = sporadicUseFlag;
    }
}
